@@ -31,7 +31,8 @@ def MATCH_AEC(refFile=None, testFile=None, caliFile=None,outFile=None,targetType
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/matchsig_aec.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/matchsig_aec.dylib')
-
+    if cur_paltform == 'Linux':
+        mydll = CDLL(sys.prefix + '/matchsig_aec.so')
     mydll.matchsig_aec.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double,c_double,POINTER(emxArray_real_T),POINTER(c_double)]
     err,fs_out,type = c_double(0.0),c_double(refsamplerate),c_double(targetType)
     mydll.matchsig_aec(byref(teststruct),byref(refstruct),byref(calistruct),refsamplerate,type,byref(outStruct),byref(err))
