@@ -50,6 +50,8 @@ def match_sig(refFile=None,testFile=None,outFile=None,audioType=0):
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/matchsig.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/matchsig.dylib')
+    if cur_paltform == 'Linux':
+        mydll = CDLL(sys.prefix + '/matchsig.so')
 
     mydll.matchsig_2.argtypes = [POINTER(emxArray_real_T), POINTER(emxArray_real_T), POINTER(emxArray_real_T),c_double,c_double,
                                      POINTER(c_double), POINTER(c_double)]
