@@ -14,7 +14,7 @@ from STI.cal_sti import cal_sti
 from STOI.STOI import cal_stoi
 from PEAQ.PEAQ import cal_peaq
 from resample.resampler import resample,restruct
-from timeAligment.time_align import cal_delay
+from timeAligment.time_align import cal_fine_delay
 import os
 import wave
 import numpy as np
@@ -36,7 +36,7 @@ from CLIPPING_DETECTION.audio_clip_detection import cal_clip_index
 allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR',
               'SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE',
               'ATTACKRELEASE','MUSICSTA','AGCDELAY','SLIENCE','FORMAT',
-              'MATCHAEC','ERLE','AECMOS','AIMOS','TRMS','ARMS','NOISE','CLIP']
+              'MATCHAEC','ERLE','AECMOS','AIMOS','TRMS','ARMS','NOISE','CLIP','DELAY']
 
 
 class computeAudioQuality():
@@ -286,6 +286,14 @@ class computeAudioQuality():
         self.__double_end_check()
         return match_sig(pcm2wav(self.refFile,sample_rate=self.samplerate), pcm2wav(self.testFile,sample_rate=self.samplerate), self.outFile,self.audioType)
 
+    def DELAY(self):
+        """
+        """
+        pass
+        self.__double_end_check()
+        return cal_fine_delay(pcm2wav(self.refFile, sample_rate=self.samplerate),
+                         pcm2wav(self.testFile, sample_rate=self.samplerate))
+
     def LOUDNESS(self):
         """
         Returns
